# aioeufyclean

This is a support library for controlling eufy robot vacuum cleaners over a local network connection.

This library is tested with a eufy Clean X8.

## Thanks

This wouldn't be possible without the work by Richard Mitchell (see https://github.com/mitchellrj/eufy_robovac) and its many forks. Thanks!
